sqltriples.PgSQLAdapter

Module sqltriples :: Class PgSQLAdapter |
[show private | hide private]
[frames | no frames]

## Class PgSQLAdapter

    Adapter --+
              |
             PgSQLAdapter

Method Summary
| `delete_sequence(self, cursor, sequence_name)`
| `init_sequence(self, cursor, sequence_name)`
Inherited from Adapter
| ``__init__`(self, connection)`
| ``delete_table`(self, cursor, table_name)`
| ``init_table`(self, cursor, table_name)`
| ``query_next_bnode_id`(self, cursor, sequence_name)`
| ``_pmark`(self, i)`
| ``_present`(self, values)`

Class Variable Summary
`str` | `paramstyle` = `'pyformat'`
`str` | `_delete_sequence` = `'drop sequence %s'`
`str` | `_delete_table` = `'drop table %s'`
`str` | `_init_sequence` = `'create sequence %s'`
`str` | `_init_table` = `'\n create table %s (\n ...`
`str` | `_query_next_bnode_id` = `"select nextval('%s')"`
Inherited from Adapter
`dict` | `paramdict` = `{'named': 1, 'format': 0, 'pyformat': 1, 'nu...`

Class Variable Details

    ### paramstyle Type: `str` Value:
        'pyformat'

    ### _delete_sequence Type: `str` Value:
        'drop sequence %s'

    ### _delete_table Type: `str` Value:
        'drop table %s'

    ### _init_sequence Type: `str` Value:
        'create sequence %s'

    ### _init_table Type: `str` Value:
        '''
                create table %s (
                    subject varchar, predicate varchar, object varchar,
                    subject_type char, object_type char,
                    context varchar,
                    primary key(subject, subject_type, predicate, object, obje\
        ct_type, context)
                )
        ...

    ### _query_next_bnode_id Type: `str` Value:
        "select nextval('%s')"

Generated by Epydoc 2.1 on Tue Mar 21 02:02:07 2006 | http://epydoc.sf.net